#include "m_item_name.h"

#include "m_name_table.h"
#include "m_lib.h"
#include "m_room_type.h"
#include "m_actor_type.h"
#include "m_font.h"

static u8 itemArt_Paper[PAPER_NUM] = {
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
};

static u8 itemArt_Money[MONEY_NUM] = {
    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
};

static u8 itemArt_Tool[TOOL_NUM] = {
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,
    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,
};

static u8 itemArt_Fish[FISH_NUM] = {
    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_AN, mIN_ARTICLE_AN, mIN_ARTICLE_A,
    mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_AN,
};

static u8 itemArt_Cloth[CLOTH_NUM] = {
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_AN,   mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,  mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_NONE, mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_AN, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
};

static u8 itemArt_Etc[ETC_NUM] = {
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_AN,
    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,
    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,
    mIN_ARTICLE_NONE,
};

static u8 itemArt_Carpet[CARPET_NUM] = {
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_AN,   mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,
    mIN_ARTICLE_A,
};

static u8 itemArt_Wall[WALL_NUM] = {
    mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_AN, mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_AN,   mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_AN,
    mIN_ARTICLE_A,  mIN_ARTICLE_AN, mIN_ARTICLE_A,    mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,  mIN_ARTICLE_AN, mIN_ARTICLE_AN,   mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_AN,   mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_AN, mIN_ARTICLE_A,  mIN_ARTICLE_A,    mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,  mIN_ARTICLE_A,  mIN_ARTICLE_NONE, mIN_ARTICLE_A,
};

static u8 itemArt_Fruit[FRUIT_NUM] = {
    mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_NONE, mIN_ARTICLE_A,
};

static u8 itemArt_Plant[PLANT_NUM] = {
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
};

static u8 itemArt_MiniDisk[MINIDISK_NUM] = {
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
};

static u8 itemArt_Diary[DIARY_NUM] = {
    mIN_ARTICLE_NONE, mIN_ARTICLE_A, mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A,
};

static u8 itemArt_Ticket[TICKET_NUM] = {
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
};

static u8 itemArt_Insect[INSECT_NUM] = {
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_AN,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,  mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_AN, mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
    mIN_ARTICLE_A, mIN_ARTICLE_A, mIN_ARTICLE_A,
};

static u8 itemArt_Hukubukuro[HUKUBUKURO_NUM] = {
    mIN_ARTICLE_A,
    mIN_ARTICLE_A,
};

static u8 itemArt_Kabu[KABU_NUM] = {
    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE,
};

static u8 ftrArt[FTR_NUM] = {
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_THE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_AN,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_THE,  mIN_ARTICLE_THE,  mIN_ARTICLE_THE,  mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_THE,  mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_AN,   mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE,
    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_THE,  mIN_ARTICLE_THE,  mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_AN,   mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
    mIN_ARTICLE_NONE, mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,
    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_A,    mIN_ARTICLE_NONE, mIN_ARTICLE_NONE,
};

/**
 * @brief Copies an item name from src to dst.
 *
 * @param dst Destination item name buffer
 * @param src Source item name buffer
 **/
static void mIN_dma_itemName(u8* dst, u8* src) {
    mem_copy(dst, src, mIN_ITEM_NAME_LEN);
}

/**
 * @brief Retrieves and copies an item name to a destination buffer from an item no.
 *
 * @param dst The item name destination buffer
 * @param item The item no whose name will be retrieved
 **/
extern void mIN_copy_name_str(u8* dst, mActor_name_t item) {
    // clang-format off
    static u8* itemName_table[ITEM1_CAT_NUM] = {
        itemName_paper,
        itemName_money,
        itemName_tool,
        itemName_fish,
        itemName_cloth,
        itemName_etc,
        itemName_carpet,
        itemName_wall,
        itemName_fruit,
        itemName_plant,
        itemName_minidisk,
        itemName_dummy,
        itemName_ticket,
        itemName_insect,
        itemName_hukubukuro,
        itemName_kabu
    };
    // clang-format on

    static u8 unknown_item_str[mIN_ITEM_NAME_LEN] = { CHAR_u,     CHAR_n,     CHAR_k,     CHAR_n,
                                                      CHAR_o,     CHAR_w,     CHAR_n,     CHAR_SPACE,
                                                      CHAR_SPACE, CHAR_SPACE, CHAR_SPACE, CHAR_SPACE,
                                                      CHAR_SPACE, CHAR_SPACE, CHAR_SPACE, CHAR_SPACE };

    u8 item_name[mIN_ITEM_NAME_LEN];
    u32 itm = item;
    mActor_name_t item_no = mRmTp_FtrItemNo2Item1ItemNo(item, FALSE);

    if (mNT_check_unknown(item_no) == TRUE) {
        mem_copy(dst, unknown_item_str, mIN_ITEM_NAME_LEN);
    } else {
        switch (ITEM_NAME_GET_TYPE(item_no)) {
            case NAME_TYPE_ITEM1: {
                mIN_dma_itemName(item_name, itemName_table[ITEM_NAME_GET_CAT(item_no)] +
                                                ITEM_NAME_GET_INDEX(item_no) * mIN_ITEM_NAME_LEN);
                mem_copy(dst, item_name, mIN_ITEM_NAME_LEN);
                break;
            }

            case NAME_TYPE_FTR0: {
                mIN_dma_itemName(item_name, ftrName_table + ((item_no / 4) & 0x3FF) * mIN_ITEM_NAME_LEN);
                mem_copy(dst, item_name, mIN_ITEM_NAME_LEN);
                break;
            }

            case NAME_TYPE_FTR1: {
                mIN_dma_itemName(item_name, ftrName2_table + ((item_no / 4) & 0x3FF) * mIN_ITEM_NAME_LEN);
                mem_copy(dst, item_name, mIN_ITEM_NAME_LEN);
                break;
            }

            default: {
                if (ITEM_IS_SIGNBOARD(item_no)) {
                    mIN_dma_itemName(item_name,
                                     itemName_table[ITEM1_CAT_ETC] + (ITM_SIGNBOARD & 0xFF) * mIN_ITEM_NAME_LEN);
                    mem_copy(dst, item_name, mIN_ITEM_NAME_LEN);
                } else if (item_no == EMPTY_NO) {
                    mem_clear(dst, mIN_ITEM_NAME_LEN, CHAR_SPACE);
                }
                break;
            }
        }
    }
}

/**
 * @brief Gets the artticle type for a given item.
 *
 * @param item The item no whose article type will be retrieved
 * @return mIN_ARTICLE_* item article
 **/
extern int mIN_get_item_article(mActor_name_t item) {
    // clang-format off
    static u8* itemArt_table[ITEM1_CAT_NUM] = {
        itemArt_Paper,
        itemArt_Money,
        itemArt_Tool,
        itemArt_Fish,
        itemArt_Cloth,
        itemArt_Etc,
        itemArt_Carpet,
        itemArt_Wall,
        itemArt_Fruit,
        itemArt_Plant,
        itemArt_MiniDisk,
        itemArt_Diary,
        itemArt_Ticket,
        itemArt_Insect,
        itemArt_Hukubukuro,
        itemArt_Kabu
    };
    // clang-format on

    int article = mIN_ARTICLE_NONE;
    mActor_name_t item_no = mRmTp_FtrItemNo2Item1ItemNo(item, FALSE);
    int index = item_no & 0xFF;

    switch (ITEM_NAME_GET_TYPE(item_no)) {
        case NAME_TYPE_ITEM1: {
            article = itemArt_table[ITEM_NAME_GET_CAT(item_no)][index];
            break;
        }

        case NAME_TYPE_FTR0:
        case NAME_TYPE_FTR1: {
            int ftr_idx = mRmTp_FtrItemNo2FtrIdx(item_no);
            if (ftr_idx < FTR_NUM) {
                return ftrArt[ftr_idx];
            }
            return mIN_ARTICLE_NONE;
        }

        default: {
            if (ITEM_IS_SIGNBOARD(item_no)) {
                article = itemArt_Etc[ITM_SIGNBOARD & 0xFF];
            }
            break;
        }
    }

    return article;
}
